picker_image_cropper library
Classes
- CropAspectRatio
- Represents an aspect ratio for cropping
- CropOverlayPainter
- Custom painter for crop overlay
- CropperLabels
- A class that contains all the text labels used in the image cropper. This allows for easy internationalization and customization of text.
- CropperTheme
- Theme configuration for the image cropper
- CropResult
- Result of image cropping operation that can contain both bytes and a file path.
- DraggableCropOverlayPainter
- Custom painter for draggable crop overlay with handles
- ImagePickerCropper
- Main widget for image picking and cropping
- ModernImageCropper
- Modern image cropper widget with professional UI.
Enums
- CropOverlayType
- Types of crop overlay shapes
- OutputFormat
- Output image format for the cropped result.
- OutputType
- Enum defining different output types for cropped images
Typedefs
- OnBytesPickerCompleted = void Function(Uint8List bytes)
- Callback for when image picking/cropping is completed with Uint8List only
- OnFilePickerCompleted = void Function(String filePath)
- Callback for when image picking/cropping is completed with file path only
- OnImagePickerCompleted = void Function(String? filePath, Uint8List? bytes)
- Callback for when image picking/cropping is completed with both file path and Uint8List